jacinle.utils.filelock
======================

.. automodule:: jacinle.utils.filelock

   
   
   .. rubric:: Module attributes

   .. autosummary::
   
      FileLock
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      BaseFileLock
      FileLock
      SoftFileLock
      UnixFileLock
      WindowsFileLock
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
      :toctree:
   
      FileLockTimeout
   
   








.. rubric:: Class BaseFileLock
.. autoclass:: BaseFileLock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class FileLock
.. autoclass:: FileLock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SoftFileLock
.. autoclass:: SoftFileLock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class UnixFileLock
.. autoclass:: UnixFileLock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class WindowsFileLock
.. autoclass:: WindowsFileLock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







